# xgbse.converters.convert_to_structured
::: xgbse.converters.convert_to_structured
    handler: python
    rendering:
      show_root_heading: false
      show_source: false

# xgbse._debiased_bce.XGBSEDebiasedBCE
::: xgbse.converters.convert_y
    handler: python
    rendering:
      show_root_heading: false
      show_source: false
